<?php

namespace Ysfdmr\Testpackage\Providers;

use Illuminate\Support\ServiceProvider;

class TestpackageServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'testpackage');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'testpackage');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('ysfdmr.testpackage', function ($app) {
            return $this->app->make('Ysfdmr\Testpackage\Testpackage');
        });

                // Bind Test to repository
        $this->app->bind(
            'Ysfdmr\Testpackage\Interfaces\TestRepositoryInterface',
            \Ysfdmr\Testpackage\Repositories\Eloquent\TestRepository::class
        );

        $this->app->register(\Ysfdmr\Testpackage\Providers\AuthServiceProvider::class);
                $this->app->register(\Ysfdmr\Testpackage\Providers\EventServiceProvider::class);
        
        $this->app->register(\Ysfdmr\Testpackage\Providers\RouteServiceProvider::class);
                $this->app->register(\Ysfdmr\Testpackage\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['ysfdmr.testpackage'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('ysfdmr/testpackage.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/testpackage')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/testpackage')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
